# Changelog

## [0.2.1](https://github.com/BfArM-MVH/grz-tools/compare/grz-db-v0.2.0...grz-db-v0.2.1) (2025-07-02)


### Bug Fixes

* **grz-db,grzctl:** address previously unchecked mypy type checks ([#247](https://github.com/BfArM-MVH/grz-tools/issues/247)) ([e51a65b](https://github.com/BfArM-MVH/grz-tools/commit/e51a65b090c891f44c6c4cc7199138d4cb15c07a))

## [0.2.0](https://github.com/BfArM-MVH/grz-tools/compare/grz-db-v0.1.0...grz-db-v0.2.0) (2025-06-30)


### Features

* **grzctl,grz-db:** Add support for change requests ([#151](https://github.com/BfArM-MVH/grz-tools/issues/151)) ([2f28d69](https://github.com/BfArM-MVH/grz-tools/commit/2f28d691b72da2d904391680ff72b1f9a3a22254))


### Bug Fixes

* **grz-db:** don't print the duplicate tanG ([#229](https://github.com/BfArM-MVH/grz-tools/issues/229)) ([718a2be](https://github.com/BfArM-MVH/grz-tools/commit/718a2be52d959be44449f6b46143be62728c2631))
* **grz-db:** Ensure author's key is ed25519 ([#204](https://github.com/BfArM-MVH/grz-tools/issues/204)) ([0f7eba2](https://github.com/BfArM-MVH/grz-tools/commit/0f7eba2652c67f3c4ddb507f7d4e197dc0c086ec))
* **grzctl,grz-db:** Add `db submission modify` to allow setting tanG/pseudonym ([#198](https://github.com/BfArM-MVH/grz-tools/issues/198)) ([b6275c3](https://github.com/BfArM-MVH/grz-tools/commit/b6275c38b134e6d334dc158c9c98631e62750b68))
* **grzctl:** improve error message on incorrect passphrase for private key ([#206](https://github.com/BfArM-MVH/grz-tools/issues/206)) ([8b73036](https://github.com/BfArM-MVH/grz-tools/commit/8b7303643b96b87bf9b095e135633fc3db3a7c7e))

## 0.1.0 (2025-06-11)


### Features

* migrate to monorepo configuration ([36c7360](https://github.com/BfArM-MVH/grz-tools/commit/36c736044ce09473cc664b4471117465c5cab9a3))
